@@ -1,5 +1,7 @@
 package Test::Environment::Plugin::Apache2::Apache2::Filter;
 
+our $VERSION = '0.01';
+
 1;
 
 package Apache2::Filter;
@@ -46,6 +48,7 @@ use base 'Class::Accessor::Fast';
     data
     max_buffer_size
     data_for_next_filter
+    seen_eos
 
 =cut
 
@@ -53,6 +56,7 @@ __PACKAGE__->mk_accessors(qw{
     ctx
     data
     max_buffer_size
+    seen_eos
 });
 
 =head1 METHODS
@@ -127,6 +131,10 @@ sub print {
 
 __END__
 
+=head1 TODO
+
+	* implement sending/setting eos
+
 =head1 AUTHOR
 
 Jozef Kutej
